#
# spec file for package libdb_java-4_8
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define         generic_name db
%define         docdir %{_defaultdocdir}/%{name}
%define         major 4
%define         minor 8

Name:           libdb_java-4_8
Version:        %{major}.%{minor}.30
Release:        31.3
Summary:        Java Bindings for the Berkeley DB
License:        BSD-3-Clause
Group:          Productivity/Databases/Servers
Url:            http://oracle.com/technetwork/products/berkeleydb/

Source:         db-%{version}.tar.bz2
Source1:        %{name}.changes
Source9:        getpatches
Patch0:         db-%{version}.patch
BuildRequires:  autoconf
BuildRequires:  gcc-c++
BuildRequires:  java-sdk >= 1.5
BuildRequires:  unzip
BuildRequires:  update-alternatives
Requires:       libdb-%{major}_%{minor} = %{version}
Provides:       db-java = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Conflicts:      libdb_java-4_5

%description
These are the Java bindings for the Berkeley DB. They are needed for
the Java support of db and dbxml.

%package        devel
Summary:        Java Bindings for the Berkeley DB
Group:          Productivity/Databases/Servers
Requires:       %{name} = %{version}
Requires:       glibc-devel
Provides:       db-java-devel = %{version}
Conflicts:      libdb_java-4_5-devel

%description    devel
These are the Java bindings for the Berkeley DB. They are needed for
the Java support of db and dbxml.

These are the development files.

%prep
%setup -q -n %{generic_name}-%{version}
%patch0
cd ..
tar -jcf %{generic_name}-%{version}.tar.bz2 %{generic_name}-%{version}

%build
cd dist
# dist/RELEASE codes the build date into the binary.
# Use last change of changes file instead
LAST_MOD=`stat --format="%Y" %SOURCE1`
DIST_DATE=`date '+%B %e, %Y' --date="@$LAST_MOD"`
sed -i -e "s/^DB_RELEASE_DATE=.*$/DB_RELEASE_DATE=\"$DIST_DATE\"/" RELEASE
./s_config
CFLAGS="%{optflags} -fno-strict-aliasing"
CC=gcc
export CFLAGS CXXFLAGS CC
#
# Build now the NPTL version
#
mkdir ../build_nptl
cd ../build_nptl
../dist/configure --prefix=%{_prefix} \
        --libdir=%{_libdir} --enable-compat185 --disable-dump185 \
        --enable-shared --disable-static --enable-cxx \
        --with-mutex="POSIX/pthreads/library" \
        --enable-java JAVACFLAGS="-source 1.5 -target 1.5" \
%ifarch %arm
        %{_target_cpu}-suse-linux-gnueabi
%else
        %{_target_cpu}-suse-linux
%endif
# Make sure O_DIRECT is really disabled (build host could have old kernel)
perl -pi -e 's/#define HAVE_O_DIRECT 1/#undef HAVE_O_DIRECT/' db_config.h
# Remove libtool predep_objects and postdep_objects wonkiness
perl -pi -e 's/^predep_objects=".*$/predep_objects=""/' libtool
perl -pi -e 's/^postdep_objects=".*$/postdep_objects=""/' libtool
perl -pi -e 's/-shared -nostdlib/-shared/' libtool

make %{?_smp_mflags} LIBSO_LIBS='$(LIBS)' LIBXSO_LIBS='$(LIBS)'" -L%{_libdir} -lstdc++"

%install
mkdir -p %{buildroot}%{_includedir}/db4
CONFIG_ARGS=$(find . -name "config.log" -exec grep "\$ \.\./dist\/configure" {} \; | sed 's/.*configure\( --.*\)/\1/g')
if [ -z "$CONFIG_ARGS" ]
then
  echo "could not find configure arguments ... exiting"
  exit 42
fi
mkdir -p %{buildroot}%{_libdir}
cd build_nptl
make prefix=%{buildroot}%{_prefix} libdir=%{buildroot}%{_libdir} strip=true install
cd ..
# make ldd happy:
chmod 755 %{buildroot}%{_libdir}/libdb*.so
# Fix header file installation
mv %{buildroot}%{_includedir}/*.h %{buildroot}%{_includedir}/db4
echo "#include <db4/db.h>" > %{buildroot}%{_includedir}/db.h
echo "#include <db4/db_185.h>" > %{buildroot}%{_includedir}/db_185.h
echo "#include <db4/db_cxx.h>" > %{buildroot}%{_includedir}/db_cxx.h
# remove dangling tags symlink from examples.
rm -f examples_cxx/tags
rm -f examples_c/tags
# Move documentation to the right directory
mkdir -p %{buildroot}%{docdir}
mv %{buildroot}%{_prefix}/docs/* %{buildroot}/%{docdir}
cp -a examples_cxx examples_c %{buildroot}/%{docdir}
cp -a LICENSE README %{buildroot}/%{docdir}
#
# Remove api documentation for C++, Java and TCL
rm -rf %{buildroot}/%{docdir}/csharp
rm -rf %{buildroot}/%{docdir}/java
rm -rf %{buildroot}/%{docdir}/api_reference/CXX
rm -rf %{buildroot}/%{docdir}/api_reference/STL
rm -rf %{buildroot}/%{docdir}/api_reference/TCL
rm -rf %{buildroot}/%{docdir}/gsg*/CXX
rm -rf %{buildroot}/%{docdir}/gsg*/JAVA
mv %{buildroot}/%{docdir}/collections/tutorial %{buildroot}/%{docdir}/
# Remove crappy *.la files
rm -rf %{buildroot}%{_libdir}/*.la
rm -rf %{buildroot}%{_libdir}/tls/*.la
pushd %{buildroot}
for file in `find | grep -v "\(java\|jar\)"`
do
  rm $file || true
done
rm -rf %{buildroot}/%{_defaultdocdir}
mkdir -p %{buildroot}/%{_javadir}
mv %{buildroot}/%{_libdir}/*.jar %{buildroot}/%{_javadir}/db-%{version}.jar
ln -sf %{_javadir}/db-%{version}.jar %{buildroot}/%{_javadir}/db.jar

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_javadir}/*
%{_libdir}/libdb_java-%{major}.%{minor}.so

%files devel
%defattr(-,root,root)
%{_libdir}/*_g.so
%{_libdir}/libdb_java.so
%{_libdir}/libdb_java-%{major}.so

%changelog
* Thu Jun 13 2013 jengelh@inai.de
- Add conflict markers against libdb-4_5 (overlapping files)
* Mon Jan  9 2012 aj@suse.de
- Do not use build date as version string.
* Thu Dec 22 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Tue Sep 27 2011 prusnak@opensuse.org
- spec cleanup
* Sat Aug 13 2011 crrodriguez@opensuse.org
- Disable static libraries
* Wed Sep 22 2010 rhafer@novell.com
- Updated to db-4.8.30. Important changes since 4.7:
  * Improved scalability and throughput when using BTree databases
    especially when running with multiple threads that equal or
    exceed the number of available CPUs.
  * Berkeley DB has added database partitioning. BTree or Hash
    databases may now be partitioned across multiple directories.
    Partitioned databases can be used to increase concurrency and to
    improve performance by spreading access across disk subsystems.
  * Berkeley DB now supports bulk insertion and deletion of data.
    Similar to the bulk get interface, the bulk put and bulk delete
    allow the developer to populate a buffer of key-value pairs and
    then pass it to the BDB library with a single API call.
  * Berkeley DB now supports compression when using BTree.
  * Berkeley DB introduces a new utility named db_sql which replaces
    db_codegen. Similar to db_codegen, db_sql accepts an input file
    with DDL statements and generates a Berkeley DB application
    using the C API that creates and performs CRUD operations on
    the defined tables. The developer can then use that code as a
    basis for further application development.
  * The Replication Manager now supports shared access to the Master
    database environment from multiple processes. In earlier
    versions, multiple process support on the Master required use
    of the Base Replication API.
  * Foreign Key Support has been added to Berkeley DB.
  * for a more detailed changelog see the changelog_4_8.html file
    in db-doc package.
- Removed db-utils-doc subpackage the utils documentation is now
  integrated with the API documentation.
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Fri Nov 21 2008 ro@suse.de
- update check-build.sh
* Wed Jul 30 2008 ro@suse.de
- changed buildreq to use any java > 1.5
* Thu Jul  5 2007 dbornkessel@suse.de
- corrected file list
- added update-alternatives to work around a ia64 problem
* Mon Jun 11 2007 dbornkessel@suse.de
- first version
